from django.db import models
from django.conf import settings
from django.utils.translation import ugettext_lazy as _
from cms.models.pagemodel import Page
from django.contrib.contenttypes.models import ContentType
from django.contrib.contenttypes.fields import GenericForeignKey
# Create your models here.


def get_app_name_models(model):
    return "{0}.{1}".format(model._meta.app_label, model._meta.object_name).lower()


class Comment(models.Model):
    POSITIVE = 1
    NEGATIVE = 2
    NEUTRAL = 3
    TYPES = (
        (POSITIVE, _("Positive")),
        (NEGATIVE, _("Negative")),
        (NEUTRAL, _("Neutral")),
    )

    user = models.ForeignKey(
        getattr(settings, 'AUTH_USER_MODEL', 'auth.User')
    )

    content_type = models.ForeignKey(ContentType, on_delete=models.CASCADE)
    object_id = models.PositiveIntegerField()
    content_object = GenericForeignKey('content_type', 'object_id')

    message = models.TextField()
    created_date = models.DateTimeField(auto_now=True)
    updated_date = models.DateTimeField(auto_now_add=True)

    comment_type = models.SmallIntegerField(choices=TYPES, default=NEUTRAL)

    def __str__(self):
        return "%s wrote at %s" % (self.user.get_full_name(),
                                   self.created_date.strftime("%b %d %Y %H:%M:%S"))


class Poll(models.Model):

    ZERO = 0
    TYPES = ((0, 0), (1, 1), (2, 2), (3, 3), (4, 4), (5, 5))
    user = models.ForeignKey(
        getattr(settings, 'AUTH_USER_MODEL', 'auth.User')
    )

    content_type = models.ForeignKey(ContentType, on_delete=models.CASCADE)
    object_id = models.PositiveIntegerField()
    content_object = GenericForeignKey('content_type', 'object_id')

    created_date = models.DateTimeField(auto_now=True)
    updated_date = models.DateTimeField(auto_now_add=True)

    poll_type = models.SmallIntegerField(choices=TYPES, default=ZERO)

    def __str__(self):
        return "%s wrote at %s" % (self.user.get_full_name(),
                                   self.created_date.strftime("%b %d %Y %H:%M:%S"))



from classytags.core import Options
from classytags.helpers import Tag
from classytags.arguments import Argument
from django import template
from django.template.loader import render_to_string
from djcms_votes.models import get_app_name_models, Poll, Comment
from djcms_votes.utils import randomword

register = template.Library()


class User_Poll_Likes(Tag):
    name = 'user_poll_likes_chart'
    options = Options(
        Argument('user', required=True),
    )

    def render_tag(self, context, user):
        if 'request' not in context:
            return ""

        object_list = Poll.objects.filter(
            user=user,
        )

        stats = {
            '1': object_list.filter(poll_type=1).count(),
            '2': object_list.filter(poll_type=2).count(),
            '3': object_list.filter(poll_type=3).count(),
            '4': object_list.filter(poll_type=4).count(),
            '5': object_list.filter(poll_type=5).count(),
        }

        return render_to_string('djcms_votes/user_poll_chart.html',
                                {'user': user,
                                 'stats': stats,
                                 'id': randomword(5)
                                 }
                                )


register.tag(User_Poll_Likes)


class User_comment_Likes(Tag):
    name = 'user_comment_likes_chart'
    options = Options(
        Argument('user', required=True),
    )

    def render_tag(self, context, user):
        if 'request' not in context:
            return ""

        object_list = Comment.objects.filter(
            user=user,
        )

        stats = {
            'positive': object_list.filter(comment_type=Comment.POSITIVE).count(),
            'negative': object_list.filter(comment_type=Comment.NEGATIVE).count(),
            'netural': object_list.filter(comment_type=Comment.NEUTRAL).count(),
        }

        return render_to_string('djcms_votes/user_comment_chart.html',
                                {'user': user,
                                 'stats': stats,
                                 'id': randomword(5)
                                 }
                                )


register.tag(User_comment_Likes)



# encoding: utf-8

'''
Free as freedom will be 24/9/2016

@author: luisza
'''

from __future__ import unicode_literals


from ajax_select import register, LookupChannel
from aldryn_newsblog.models import Article
from django.db.models.query_utils import Q
from aldryn_people.models import Person, Group
from aldryn_categories.models import Category


@register('articles')
class ArticleLookup(LookupChannel):

    model = Article

    def get_query(self, q, request):
        return self.model.objects.filter(
            Q(translations__title__icontains=q
              ) | Q(translations__lead_in__icontains=q)
        ).order_by('translations__slug')[:20]

    def format_item_display(self, item):
        return u"<span class='tag'>%s</span>" % item.title


@register('categories')
class CategoryLookup(LookupChannel):

    model = Category

    def get_query(self, q, request):
        return self.model.objects.filter(
            translations__name__icontains=q).order_by('translations__name')[:20]

    def format_item_display(self, item):
        return u"<span class='tag'>%s</span>" % item.name


@register('people')
class PeopleLookup(LookupChannel):

    model = Person

    def get_query(self, q, request):
        return self.model.objects.filter(
            Q(translations__name__icontains=q
              ) | Q(user__first_name__icontains=q
                    ) | Q(user__last_name__icontains=q)
        ).order_by('translations__name')[:20]

    def format_item_display(self, item):
        return u"<span class='tag'>%s</span>" % item.name


@register('groups')
class GroupLookup(LookupChannel):

    model = Group

    def get_query(self, q, request):
        return self.model.objects.filter(
            Q(translations__name__icontains=q
              ) | Q(translations__description__icontains=q)).order_by(
                  'translations__name')[:20]

    def format_item_display(self, item):
        return u"<span class='tag'>%s</span>" % item.name



# encoding: utf-8

'''
Free as freedom will be 11/9/2016

@author: luisza
'''

from __future__ import unicode_literals

from classytags.core import Options
from classytags.helpers import Tag
from classytags.arguments import Argument
from django import template
from django.utils.translation import ugettext_lazy as _
from django.template.loader import render_to_string
from djcms_votes.forms import UserCommentForm
from djcms_votes.models import get_app_name_models
from djcms_votes.utils import render_votes, render_polls, render_poll_likes
from djcms_votes.forms import LoginForm

register = template.Library()


class Render_Comments(Tag):
    name = 'render_comments'
    options = Options(
        Argument('page', required=True),
    )

    def render_tag(self, context, page):
        if 'request' not in context:
            return ""
        else:
            request = context['request']
            user = request.user
        if not user.is_active:
            return render_to_string(
                'djcms_votes/login.html',
                {'form': LoginForm(),
                 'next': request.path},
                request=request
            )

        if user.is_superuser:
            appname, model = get_app_name_models(page).split(".")
            return render_to_string('djcms_votes/comments_display.html',
                                    {'page': page,
                                     'appname': appname,
                                     'model': model,

                                     })

        return render_to_string('djcms_votes/comment_form.html',
                                {'page': page,
                                 'appname': get_app_name_models(page),
                                 'request': request,
                                 'form': UserCommentForm})

register.tag(Render_Comments)


class Render_Chart(Tag):
    name = 'render_comment_chart'
    options = Options(
        Argument('page', required=True),
    )

    def render_tag(self, context, page):
        if 'request' not in context:
            return ""
        else:
            request = context['request']
            user = request.user
        if not user.is_superuser:
            return ""

        return render_votes(page)

register.tag(Render_Chart)


class Render_Poll(Tag):
    name = 'render_poll'
    options = Options(
        Argument('page', required=True),
    )

    def render_tag(self, context, page):
        if 'request' not in context:
            return ""
        else:
            request = context['request']
            user = request.user
        # if not user.is_superuser:
        #    return ""

        return render_polls(page)

register.tag(Render_Poll)


class Render_Poll_Likes(Tag):
    name = 'render_poll_likes'
    options = Options(
        Argument('page', required=True),
    )

    def render_tag(self, context, page):
        if 'request' not in context:
            return ""
        else:
            request = context['request']
            user = request.user
        if user is None or user.is_anonymous():
            return _("Loggin to rate")
        # if not user.is_superuser:
        #    return ""
        appname, model = get_app_name_models(page).split(".")
        return render_poll_likes(appname, model, page.pk, user)

register.tag(Render_Poll_Likes)



# encoding: utf-8

'''
Free as freedom will be 24/9/2016

@author: luisza
'''

from __future__ import unicode_literals
from django.views.generic.list import ListView
from djcms_votes.models import Poll, Comment
from djcms_votes.forms import PollsForm
from django.views.generic.edit import ProcessFormView
from aldryn_people.models import Person
from aldryn_newsblog.models import Article
from django.contrib.contenttypes.models import ContentType

from django.utils.translation import ugettext_lazy as _


class PollList(ListView, ProcessFormView):
    model = Poll
    template_name = 'djcms_votes/app/poll_list.html'
    form = PollsForm

    def get_contenttype_page(self):
        return ContentType.objects.get(app_label="aldryn_newsblog",
                                       model="article")

    def get_person_by_group(self, pks):
        people = [x[0] for x in Person.objects.filter(
            groups__pk__in=pks).values_list('pk')]

        return set(people)

    def get_articles(self, pks):
        articles = [x[0]
                    for x in Article.objects.filter(pk__in=pks).values_list('pk')]
        return set(articles)

    def get_articles_by_categories(self, pks):
        articles = [x[0]
                    for x in Article.objects.filter(
                        categories__pk__in=pks).values_list('pk')]
        return set(articles)

    def filter_query_with_form(self, form, query):
        if 'people' in form.cleaned_data and form.cleaned_data['people']:
            query = query.filter(
                user__persons__pk__in=form.cleaned_data['people'])

        if 'groups' in form.cleaned_data and form.cleaned_data['groups']:
            # FIXME: could be like, but sqlite not support distinct
            #
            query = query.filter(
                user__persons__pk__in=self.get_person_by_group(
                    form.cleaned_data['groups'])
            )
        if 'start_date' in form.cleaned_data and form.cleaned_data['start_date']:
            query = query.filter(
                created_date__gte=form.cleaned_data['start_date']
            )
        if 'end_date' in form.cleaned_data and form.cleaned_data['end_date']:
            query = query.filter(
                created_date__lte=form.cleaned_data['end_date']
            )

        if 'articles' in form.cleaned_data and form.cleaned_data['articles']:
            query = query.filter(
                content_type=self.get_contenttype_page(),
                object_id__in=self.get_articles(
                    form.cleaned_data['articles'])
            )
        if 'categories' in form.cleaned_data and form.cleaned_data['categories']:
            query = query.filter(
                content_type=self.get_contenttype_page(),
                object_id__in=self.get_articles_by_categories(
                    form.cleaned_data['categories'])
            )
        return query

    def get_queryset(self):
        form = self.get_form()
        query = ListView.get_queryset(self)
        if self.request.method == "POST":
            if form.is_valid():
                query = self.filter_query_with_form(form, query)
            else:
                query = query.none()
        return query

    def form_valid(self, form):
        return self.get(self.request)

    def form_invalid(self, form):
        return self.get(self.request)

    def get_form(self):
        if self.request.method == 'POST':
            form = self.form(self.request.POST)
            form.is_valid()
            return form
        return self.form()

    def get_form_context(self, context):
        context['form'] = self.get_form()
        return context

    def get_poll_stats(self, context):
        stats = {
            'data': [context['object_list'].filter(poll_type=6 - x).count()
                     for x in range(1, 6)],
            'label': ['\u2605' * (6 - x) for x in range(1, 6)]
        }
        stats['display'] = zip(stats['label'], stats['data'])
        context['total_polls'] = stats
        return context

    def get_comment_stats(self, context):
        query = Comment.objects.all()
        if self.request.method == "POST":
            form = self.get_form()
            if form.is_valid():
                query = self.filter_query_with_form(form, query)

        stats = {
            'data': [
                query.filter(comment_type=Comment.POSITIVE).count(),
                query.filter(comment_type=Comment.NEGATIVE).count(),
                query.filter(comment_type=Comment.NEUTRAL).count(),
            ],
            'label': [_('Positive'), _('Negative'), _('Neutral')]
        }
        stats['display'] = zip(stats['label'], stats['data'])
        context['total_comment'] = stats

        return context

    def get_context_data(self, **kwargs):
        context = ListView.get_context_data(self, **kwargs)
        context = self.get_poll_stats(context)
        context = self.get_form_context(context)
        context = self.get_comment_stats(context)
        return context



# encoding: utf-8

'''
Free as freedom will be 12/9/2016

@author: luisza
'''

from __future__ import unicode_literals


from django.contrib.auth.forms import AuthenticationForm
from django import forms
from djcms_votes.models import Comment
from ajax_select.fields import AutoCompleteSelectMultipleField


class PollsForm(forms.Form):
    articles = AutoCompleteSelectMultipleField('articles', required=False)
    categories = AutoCompleteSelectMultipleField('categories', required=False)

    people = AutoCompleteSelectMultipleField('people', required=False)
    groups = AutoCompleteSelectMultipleField('groups', required=False)

    start_date = forms.DateField(required=False)
    end_date = forms.DateField(required=False)


class UserCommentForm(forms.ModelForm):
    page = forms.IntegerField(widget=forms.HiddenInput)
    appname = forms.CharField(widget=forms.HiddenInput)
    url = forms.URLField()

    class Meta:
        model = Comment
        fields = ["message", ]

# If you don't do this you cannot use Bootstrap CSS


class LoginForm(AuthenticationForm):
    username = forms.CharField(label="Username", max_length=30,
                               widget=forms.TextInput(attrs={'class': 'form-control', 'name': 'username'}))
    password = forms.CharField(label="Password", max_length=30,
                               widget=forms.PasswordInput(
                                   attrs={'class': 'form-control', 'name': 'password'}))



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djcms_votes', '0002_poll'),
    ]

    operations = [
        migrations.AlterField(
            model_name='poll',
            name='poll_type',
            field=models.SmallIntegerField(default=0, choices=[(0, 0), (1, 1), (2, 2), (3, 3), (4, 4), (5, 5)]),
        ),
    ]



# encoding: utf-8

'''
Free as freedom will be 25/9/2016

@author: luisza
'''

from __future__ import unicode_literals
from django.core.mail import send_mail
from django.conf import settings
from django.template.loader import render_to_string


def send_comment(extra_context):

    send_mail("[site comment] %s" % (extra_context['subject']),
              extra_context['message'],
              settings.DEFAULT_FROM_EMAIL,
              settings.COMMENT_EMAIL_NOTIFICATION,
              fail_silently=True,
              html_message=render_to_string('djcms_votes/mail/comment.html',
                                            extra_context))



# encoding: utf-8

'''
Free as freedom will be 11/9/2016

@author: luisza
'''

from __future__ import unicode_literals

from django_ajax.mixin import AJAXMixin
from django.views.generic.edit import CreateView
from djcms_votes.models import Comment, Poll
# Create your views here.

from django.utils.translation import ugettext_lazy as _
from django.contrib.contenttypes.models import ContentType
from djcms_votes.forms import UserCommentForm
from django_ajax.decorators import ajax
from django.template.loader import render_to_string
from django.views.generic.list import ListView
from django.contrib.auth.decorators import login_required
from djcms_votes.utils import render_votes, render_polls, render_poll_likes
from django.shortcuts import render, get_object_or_404
from django.contrib.auth import get_user_model
from djcms_votes.mail import send_comment


class CreateComment(AJAXMixin, CreateView):
    model = Comment
    form_class = UserCommentForm
    success_url = "/"

    def form_valid(self, form):
        app_label, model = form.cleaned_data['appname'].split(".")
        page_type = ContentType.objects.get(app_label=app_label,
                                            model=model)
        page = page_type.get_object_for_this_type(pk=form.cleaned_data['page'])
        if not page:
            raise
        self.object = form.save(commit=False)
        self.object.user = self.request.user
        self.object.content_object = page
        self.object.save()
        context = {
            'subject': _("New comment available"),
            'message': self.object.message,
            'page': page,
            'comment': self.object,
            'request': self.request,
            'url': form.cleaned_data['url']

        }
        send_comment(context)
        return {
            'fragments': {
                '#comment_field': _("Thanks, your comment was received")
            },
        }

    def form_invalid(self, form):
        response = CreateView.form_invalid(self, form)
        response.render()
        return {
            'fragments': {
                '#comment_field': response.content
            },
        }


class ListComment(AJAXMixin, ListView):
    model = Comment
    paginate_by = 10

    def extract_get_params(self):
        self.page_appname = self.request.GET.get("appname", None)
        self.page_model = self.request.GET.get("model", None)
        self.page_pk = self.request.GET.get("pk", None)
        return all((self.page_appname, self.page_model, self.page_pk))

    def get_queryset(self):
        queryset = ListView.get_queryset(self)

        if not self.request.user.is_superuser:
            return queryset.none()

        if not self.extract_get_params():
            return queryset.none()

        queryset = queryset.filter(
            content_type=ContentType.objects.get(
                app_label=self.page_appname,
                model=self.page_model
            ),
            object_id=self.page_pk
        )
        return queryset

    def get_context_data(self, **kwargs):
        context = ListView.get_context_data(self, **kwargs)
        context['appname'] = self.page_appname
        context['model'] = self.page_model
        context['pk'] = self.page_pk
        return context

    def get(self, request, *args, **kwargs):
        response = ListView.get(self, request, *args, **kwargs)
        response.render()
        return {
            'fragments': {
                '#comment_list': response.content
            },
        }


@ajax
@login_required
def comment_vote(request, pk, vote):
    dev = ""
    try:
        if request.user.is_superuser:
            if vote in ['1', '2', '3']:
                comment = Comment.objects.get(pk=pk)
                comment.comment_type = int(vote)
                comment.save()
                dev = render_to_string(
                    'djcms_votes/likes.html',
                    {'object': comment,
                     'pk': pk}
                )
    except:
        pass
    return {
        'fragments': {
            '#comment_vote_%(pk)s' % {'pk': pk}: dev
        },
    }


@ajax
@login_required
def show_comment_chart(request, appname, model, pk):
    pagect = ContentType.objects.get(app_label=appname, model=model)
    page = pagect.get_object_for_this_type(pk=pk)
    dev = ""
    if request.user.is_superuser:
        dev = render_votes(page, as_view=True)
    return {
        'fragments': {
            '#comment_chart': dev
        },
    }


@ajax
@login_required
def poll_vote(request, appname, model, pk, vote):
    dev = ""
    try:
        if vote in ['1', '2', '3', '4', '5']:
            poll = Poll.objects.get(
                content_type=ContentType.objects.get(
                    app_label=appname,
                    model=model
                ),
                object_id=pk,
                user=request.user
            )
            poll.poll_type = int(vote)
            poll.save()
            dev = render_poll_likes(
                appname, model, pk, request.user, poll=poll)
    except:
        pass
    return {
        'fragments': {
            '#poll_vote': dev
        },
    }


@ajax
def show_poll_chart(request, appname, model, pk):
    pagect = ContentType.objects.get(app_label=appname, model=model)
    page = pagect.get_object_for_this_type(pk=pk)
    dev = render_polls(page, as_view=True)
    return {
        'fragments': {
            '#poll_chart': dev
        },
    }


@ajax
@login_required
def comments_per_user(request, user):
    # FIXME: usuario solo con permisos puede ver esto
    User = get_user_model()
    user = get_object_or_404(User, pk=user)
    object_list = Comment.objects.filter(
        user=user
    )

    stats = {
        'positive': object_list.filter(comment_type=Comment.POSITIVE).count(),
        'negative': object_list.filter(comment_type=Comment.NEGATIVE).count(),
        'neutral': object_list.filter(comment_type=Comment.NEUTRAL).count(),
    }
    return render(request, 'djcms_votes/user_votes.html', {
        'user': user,
        'stats': stats
    })


@login_required
def get_stats(request):
    pass



# encoding: utf-8

'''
Free as freedom will be 12/9/2016

@author: luisza
'''

from __future__ import unicode_literals
from djcms_votes.models import get_app_name_models, Comment, Poll
from django.contrib.contenttypes.models import ContentType
from django.template.loader import render_to_string
import uuid


def randomword(length):
    return str(uuid.uuid4())[0:length]


def render_votes(page, as_view=False):
    appname, model = get_app_name_models(page).split(".")
    object_list = Comment.objects.filter(
        content_type=ContentType.objects.get(
            app_label=appname,
            model=model
        ),
        object_id=page.pk
    )
    stats = {
        'positive': object_list.filter(comment_type=Comment.POSITIVE).count(),
        'negative': object_list.filter(comment_type=Comment.NEGATIVE).count(),
        'neutral': object_list.filter(comment_type=Comment.NEUTRAL).count(),
    }

    appname, model = get_app_name_models(page).split(".")

    return render_to_string('djcms_votes/comment_chart.html',
                            {'page': page,
                             'object_list': object_list,
                             'appname': appname,
                             'model': model,
                             'stats': stats,
                             'as_view': as_view}
                            )


def render_polls(page, as_view=False):
    appname, model = get_app_name_models(page).split(".")
    object_list = Poll.objects.filter(
        content_type=ContentType.objects.get(
            app_label=appname,
            model=model
        ),
        object_id=page.pk
    )
    stats = {
        '1': object_list.filter(poll_type=1).count(),
        '2': object_list.filter(poll_type=2).count(),
        '3': object_list.filter(poll_type=3).count(),
        '4': object_list.filter(poll_type=4).count(),
        '5': object_list.filter(poll_type=5).count(),
    }

    appname, model = get_app_name_models(page).split(".")
    return render_to_string('djcms_votes/poll_chart.html',
                            {'page': page,
                             'object_list': object_list,
                             'appname': appname,
                             'model': model,
                             'stats': stats,
                             'as_view': as_view}
                            )


def render_poll_likes(appname, model, page_pk, user, poll=None):

    if poll is None:
        poll, created = Poll.objects.get_or_create(
            content_type=ContentType.objects.get(
                app_label=appname,
                model=model
            ),
            object_id=page_pk,
            user=user,
        )

    return render_to_string('djcms_votes/poll_likes.html',
                            {'object': poll,
                             'appname': appname,
                             'model': model,
                             'pk': page_pk,
                             'stars': [1, 2, 3, 4, 5]
                             }
                            )



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.utils.translation import ugettext_lazy as _

from cms.app_base import CMSApp
from cms.apphook_pool import apphook_pool

from . import DEFAULT_APP_NAMESPACE


class Djcms_VotesApp(CMSApp):
    name = _('Votes')
    urls = ['djcms_votes.app_urls']
    app_name = DEFAULT_APP_NAMESPACE

apphook_pool.register(Djcms_VotesApp)





from django.conf.urls import url
from djcms_votes import views
from django.contrib.auth.decorators import login_required
from djcms_votes.views import ListComment, comment_vote, get_stats

urlpatterns = [
    url(r'^create$', login_required(
        views.CreateComment.as_view()), name="comment_create"),

    url(r'list$', login_required(views.ListComment.as_view()),
        name="comment_list"),

    url(r'vote_comment/(?P<pk>\d+)/(?P<vote>\d+)$',
        views.comment_vote, name="comment_vote"),
    url(r'vote_poll/(?P<appname>\w+)/(?P<model>\w+)/(?P<pk>\d+)/(?P<vote>\d+)$',
        views.poll_vote, name="poll_vote"),
    url(r'vote_comment_char/(?P<appname>\w+)/(?P<model>\w+)/(?P<pk>\d+)$', views.show_comment_chart,
        name="vote_comment_chart"),
    url(r'poll_char/(?P<appname>\w+)/(?P<model>\w+)/(?P<pk>\d+)$', views.show_poll_chart,
        name="poll_chart"),
    url(r'user_votes/(?P<user>\d+)$',
        views.comments_per_user, name="user_votes"),

    url(r'vote_stats', get_stats, name="vote_stats")

]



from setuptools import setup, find_packages
import os

CLASSIFIERS = [
    'Environment :: Web Environment',
	'Framework :: Django',
	'Framework :: Django :: 1.8',
	'Framework :: Django :: 1.9',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Programming Language :: Python :: 3.5',
    'Topic :: Internet :: WWW/HTTP',
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
	'Topic :: Software Development :: Libraries :: Python Modules',
	'Development Status :: 4 - Beta',
]

README = open(os.path.join(os.path.dirname(__file__), 'README.rst')).read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))



setup(
    author='Luis Zarate',
    author_email='luis.zarate@solvosoft.com',
    name='djangocms-votes',
    version='0.0.2',
    description='Django cms comments, and rate system with stats.',
    long_description=README,
    url='https://github.com/luisza/djangocms-votes',
    license='GNU General Public License v3 (GPLv3)',
    platforms=['OS Independent'],
    classifiers=CLASSIFIERS,
    install_requires=[
		"django>=1.8",
		"django-cms>=3.3.2",
		"aldryn-newsblog==1.3.0",
		"djangoajax",
    ],
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False
)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('djcms_votes', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Poll',
            fields=[
                ('id', models.AutoField(serialize=False, verbose_name='ID', primary_key=True, auto_created=True)),
                ('object_id', models.PositiveIntegerField()),
                ('created_date', models.DateTimeField(auto_now=True)),
                ('updated_date', models.DateTimeField(auto_now_add=True)),
                ('poll_type', models.SmallIntegerField(choices=[(1, 'Positive'), (2, 'Negative'), (3, 'Neutral')], default=3)),
                ('content_type', models.ForeignKey(to='contenttypes.ContentType')),
                ('user', models.ForeignKey(to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
